class Trail < ActiveRecord::Base
  has_many :guideposts, :through => :signs
  has_many :signs, -> { order(:km) }, inverse_of: :trail, dependent: :destroy
  belongs_to :osm_trail, foreign_key: :osmid, primary_key: :osmid
  belongs_to :kct_trail, foreign_key: :kctref, primary_key: :kctref
  has_many :notes
  include TrailCommons

  def read_from(object)
    self.attributes = object.attributes.reject{|k,v| k=='id'}
  end

  def self.new_from_object(object)
    result = Trail.new
    result.read_from(object)
    result
  end
  
  def to_s; "dbf:#{id}"  end
  def inspect_nazev
    if nazev.blank?
      "Turistická značka č. #{kctref}"
    else
      "TZ#{kctref} #{nazev}"
    end
  end
  
  def initialize_km
    signs.each do |sign|
      sign.km = sign.osm_sign.andand.km
    end
  end
  
  def merge_reasons_and_score(kct_guidepost,osm_guidepost)
    @none = [nil,0]
    @kct_trail = self.kct_trail; return @none if @kct_trail.nil? or !kct_guidepost.on?(@kct_trail)
    
    score = 0; reasons=[]
    
    # guideposts themselves without the trail
    Guidepost.merge_reasons_and_score(kct_guidepost,osm_guidepost)
  end
  
  # returns number which denotes (not normalized) probability that 
  # these two represent same guidepost on THIS trail
  def self.merge_score(kct_guidepost,osm_guidepost)
    merge_reasons_and_score(kct_guidepost,osm_guidepost)[1]
  end
  # returns textual reasons for merge
  def self.merge_reasons(kct_guidepost,osm_guidepost)
    merge_reasons_and_score(kct_guidepost,osm_guidepost)[0]
  end

  def priority
    kct_trail.andand.priority || osm_trail.andand.priority
  end
  
  def self.symbol; '~' end
  
  def prenes_kilometraz_z_osm!
    signs.each do |sign|
      sign.update_km_from_osm!
      sign.save!
    end
  end
  
  # zkontroluje zda jdou automaticky inicialicializovat barvy a typy (podobne stusku tlacitka "Zelené"
  def initialize_color_and_type?
    result = false
    # barva
    pombarva=osm_trail.andand.barva
    if self.barva.nil? and !pombarva.nil? and (pombarva == kct_trail.andand.barva)
      self.barva = pombarva
      result = true
    end
    
    # typ
    pomtyp=osm_trail.andand.typ
    if self.typ.nil? and !pomtyp.nil? and (pomtyp == kct_trail.andand.typ)
      self.typ = pomtyp
      result = true
    end
    result
  end

  def self.find_by_kctref(kctref)
    kctref.blank? ? nil : super(kctref)
  end
end









